# Flask Babeled

Implements i18n and l10n support for Flask.  This is based on the Python
babel module as well as pytz both of which are installed automatically
for you if you install this library.

This is a fork of [Flask-Babel](https://github.com/python-babel/flask-babel). I
have a need of this for work I am currently doing, and wish to modify it as
support for the original project seems to have disappeared. Will attempt to
maintain identical functionality but provide a separate package.

* [documentation](http://packages.python.org/Flask-Babeled)
* [development version](http://github.com/jeremyosborne/flask-babeled/zipball/master#egg=Flask-Babeled-dev)
* [Babel](http://babel.edgewall.org/)
